
From: Benoit Boissinot <benoit.boissinot@ens-lyon.org>

The following patch should catch all the other calls with GFP_DMA and
without either GFP_KERNEL or GFP_ATOMIC.

Signed-off-by: Benoit Boissinot <benoit.boissinot@ens-lyon.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/s390/appldata/appldata_os.c        |    2 +-
 drivers/net/b44.c                       |    2 +-
 drivers/net/wireless/hostap/hostap_hw.c |    2 +-
 drivers/s390/net/claw.c                 |   10 +++++-----
 drivers/scsi/pluto.c                    |    2 +-
 5 files changed, 9 insertions(+), 9 deletions(-)

diff -puN arch/s390/appldata/appldata_os.c~fix-invalid-kmalloc-flags-gfp_dma-alone arch/s390/appldata/appldata_os.c
--- devel/arch/s390/appldata/appldata_os.c~fix-invalid-kmalloc-flags-gfp_dma-alone	2005-08-06 15:04:13.000000000 -0700
+++ devel-akpm/arch/s390/appldata/appldata_os.c	2005-08-06 15:04:13.000000000 -0700
@@ -194,7 +194,7 @@ static int __init appldata_os_init(void)
 	P_DEBUG("sizeof(os) = %i, sizeof(os_cpu) = %lu\n", size,
 		sizeof(struct appldata_os_per_cpu));
 
-	appldata_os_data = kmalloc(size, GFP_DMA);
+	appldata_os_data = kmalloc(size, GFP_DMA|GFP_KERNEL);
 	if (appldata_os_data == NULL) {
 		P_ERROR("No memory for %s!\n", ops.name);
 		rc = -ENOMEM;
diff -puN drivers/net/b44.c~fix-invalid-kmalloc-flags-gfp_dma-alone drivers/net/b44.c
--- devel/drivers/net/b44.c~fix-invalid-kmalloc-flags-gfp_dma-alone	2005-08-06 15:04:13.000000000 -0700
+++ devel-akpm/drivers/net/b44.c	2005-08-06 15:04:13.000000000 -0700
@@ -633,7 +633,7 @@ static int b44_alloc_rx_skb(struct b44 *
 		/* Sigh... */
 		pci_unmap_single(bp->pdev, mapping, RX_PKT_BUF_SZ,PCI_DMA_FROMDEVICE);
 		dev_kfree_skb_any(skb);
-		skb = __dev_alloc_skb(RX_PKT_BUF_SZ,GFP_DMA);
+		skb = __dev_alloc_skb(RX_PKT_BUF_SZ,GFP_ATOMIC|GFP_DMA);
 		if (skb == NULL)
 			return -ENOMEM;
 		mapping = pci_map_single(bp->pdev, skb->data,
diff -puN drivers/net/wireless/hostap/hostap_hw.c~fix-invalid-kmalloc-flags-gfp_dma-alone drivers/net/wireless/hostap/hostap_hw.c
--- devel/drivers/net/wireless/hostap/hostap_hw.c~fix-invalid-kmalloc-flags-gfp_dma-alone	2005-08-06 15:04:13.000000000 -0700
+++ devel-akpm/drivers/net/wireless/hostap/hostap_hw.c	2005-08-06 15:04:13.000000000 -0700
@@ -3311,7 +3311,7 @@ prism2_init_local_data(struct prism2_hel
 
 #if defined(PRISM2_PCI) && defined(PRISM2_BUS_MASTER)
 	local->bus_m0_buf = (u8 *) kmalloc(sizeof(struct hfa384x_tx_frame) +
-					   PRISM2_DATA_MAXLEN, GFP_DMA);
+					   PRISM2_DATA_MAXLEN, GFP_ATOMIC|GFP_DMA);
 	if (local->bus_m0_buf == NULL)
 		goto fail;
 #endif /* PRISM2_PCI and PRISM2_BUS_MASTER */
diff -puN drivers/s390/net/claw.c~fix-invalid-kmalloc-flags-gfp_dma-alone drivers/s390/net/claw.c
--- devel/drivers/s390/net/claw.c~fix-invalid-kmalloc-flags-gfp_dma-alone	2005-08-06 15:04:13.000000000 -0700
+++ devel-akpm/drivers/s390/net/claw.c	2005-08-06 15:04:13.000000000 -0700
@@ -2199,7 +2199,7 @@ init_ccw_bk(struct net_device *dev)
         */
         if (privptr->p_buff_ccw==NULL) {
                 privptr->p_buff_ccw=
-			(void *)__get_free_pages(__GFP_DMA,
+			(void *)__get_free_pages(__GFP_DMA|GFP_KERNEL,
 		        (int)pages_to_order_of_mag(ccw_pages_required ));
                 if (privptr->p_buff_ccw==NULL) {
                         printk(KERN_INFO "%s: %s()  "
@@ -2355,7 +2355,7 @@ init_ccw_bk(struct net_device *dev)
         if (privptr->p_buff_write==NULL) {
             if (privptr->p_env->write_size < PAGE_SIZE) {
                 privptr->p_buff_write=
-			(void *)__get_free_pages(__GFP_DMA,
+			(void *)__get_free_pages(__GFP_DMA|GFP_KERNEL,
 			(int)pages_to_order_of_mag(claw_write_pages ));
                 if (privptr->p_buff_write==NULL) {
                         printk(KERN_INFO "%s: %s() __get_free_pages for write"
@@ -2414,7 +2414,7 @@ init_ccw_bk(struct net_device *dev)
            {
                privptr->p_write_free_chain=NULL;
                for (i = 0; i< privptr->p_env->write_buffers ; i++) {
-                   p_buff=(void *)__get_free_pages(__GFP_DMA,
+                   p_buff=(void *)__get_free_pages(__GFP_DMA|GFP_KERNEL,
 		        (int)pages_to_order_of_mag(
 			privptr->p_buff_pages_perwrite) );
 #ifdef IOTRACE
@@ -2490,7 +2490,7 @@ init_ccw_bk(struct net_device *dev)
         if (privptr->p_buff_read==NULL) {
             if (privptr->p_env->read_size < PAGE_SIZE)  {
                 privptr->p_buff_read=
-			(void *)__get_free_pages(__GFP_DMA,
+			(void *)__get_free_pages(__GFP_DMA|GFP_KERNEL,
 			(int)pages_to_order_of_mag(claw_read_pages) );
                 if (privptr->p_buff_read==NULL) {
                         printk(KERN_INFO "%s: %s() "
@@ -2604,7 +2604,7 @@ init_ccw_bk(struct net_device *dev)
 		dev->name,__FUNCTION__);
 #endif
                 for (i=0 ; i< privptr->p_env->read_buffers ; i++) {
-                        p_buff = (void *)__get_free_pages(__GFP_DMA,
+                        p_buff = (void *)__get_free_pages(__GFP_DMA|GFP_KERNEL,
 				(int)pages_to_order_of_mag(privptr->p_buff_pages_perread) );
                         if (p_buff==NULL) {
                                 printk(KERN_INFO "%s: %s() __get_free_pages for read "
diff -puN drivers/scsi/pluto.c~fix-invalid-kmalloc-flags-gfp_dma-alone drivers/scsi/pluto.c
--- devel/drivers/scsi/pluto.c~fix-invalid-kmalloc-flags-gfp_dma-alone	2005-08-06 15:04:13.000000000 -0700
+++ devel-akpm/drivers/scsi/pluto.c	2005-08-06 15:04:13.000000000 -0700
@@ -117,7 +117,7 @@ int __init pluto_detect(Scsi_Host_Templa
 #endif
 			return 0;
 	}
-	fcs = (struct ctrl_inquiry *) kmalloc (sizeof (struct ctrl_inquiry) * fcscount, GFP_DMA);
+	fcs = (struct ctrl_inquiry *) kmalloc (sizeof (struct ctrl_inquiry) * fcscount, GFP_DMA|GFP_KERNEL);
 	if (!fcs) {
 		printk ("PLUTO: Not enough memory to probe\n");
 		return 0;
_
